<?php

namespace App\Http\Controllers;

use App\Models\Expense;
use App\Models\Restaurant;
use App\Models\Revenue;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Schema;

class Admin extends Controller{

    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate');
    }
    public function index(Request $request){
        $from = Carbon::now()->startOfMonth();
        if($request->has('from')){
            $from = Carbon::parse($request->from);
        }
        $to = Carbon::now()->endOfMonth();
        if($request->has('to')){
            $to = Carbon::parse($request->to);
        }

        $dateDiff = $to->diffInDays($from) + 1;
        $previousFrom = $from->copy()->subDays($dateDiff);
        $previousTo = $to->copy()->subDays($dateDiff);

        $restaurantIds = Restaurant::pluck('id')->toArray();
        if($request->has('restaurant_id')){
            $restaurantIds = $request->input('restaurant_id', []);
        }
        $restaurants = Restaurant::pluck('name', 'id');

        // Fetch current period data
        $totalRevenue = Revenue::whereIn('restaurant_id', $restaurantIds)
            ->whereBetween('revenue_date', [$from, $to])
            ->sum('revenue_after_commission');

        $totalExpense = Expense::whereIn('restaurant_id', $restaurantIds)
            ->whereBetween('expense_date', [$from, $to])
            ->sum('amount');

        $numberOfTransactions = Revenue::whereIn('restaurant_id', $restaurantIds)
            ->whereBetween('revenue_date', [$from, $to])
            ->sum('number_of_transaction');

        // Fetch previous period data
        $previousTotalRevenue = Revenue::whereIn('restaurant_id', $restaurantIds)
            ->whereBetween('revenue_date', [$previousFrom, $previousTo])
            ->sum('revenue_after_commission');

        $previousTotalExpense = Expense::whereIn('restaurant_id', $restaurantIds)
            ->whereBetween('expense_date', [$previousFrom, $previousTo])
            ->sum('amount');

        $previousNumberOfTransactions = Revenue::whereIn('restaurant_id', $restaurantIds)
            ->whereBetween('revenue_date', [$previousFrom, $previousTo])
            ->sum('number_of_transaction');

        // Calculate revenue per transaction
        $revenuePerTransaction = round($numberOfTransactions > 0 ? $totalRevenue / $numberOfTransactions : 0, 2);
        $previousRevenuePerTransaction = round($previousNumberOfTransactions > 0 ? $previousTotalRevenue / $previousNumberOfTransactions : 0, 2);

        // Calculate gross profit margin and net profit margin
        $grossProfitMargin = $totalRevenue - $totalExpense;
        $netProfitMargin = $grossProfitMargin - ($totalExpense * 0.1); // Example calculation, adjust as needed

        // Calculate previous gross profit margin and net profit margin
        $previousGrossProfitMargin = $previousTotalRevenue - $previousTotalExpense;
        //return $grossProfitMargin;
        $previousNetProfitMargin = $previousGrossProfitMargin - ($previousTotalExpense * 0.1); // Example calculation, adjust as needed


        // Prepare chart data
        $chartData = [
            'labels' => ['Income', 'Expenses', 'Profit'],
            'previousValues' => [
                $previousTotalRevenue, $previousTotalExpense, $previousGrossProfitMargin
            ],
            'currentValues' => [
                $totalRevenue, $totalExpense, $grossProfitMargin
            ]
        ];


        return view('admin.dashboard', compact(
            'restaurants',
            'totalRevenue',
            'totalExpense',
            'numberOfTransactions',
            'revenuePerTransaction',
            'previousTotalRevenue',
            'previousTotalExpense',
            'previousNumberOfTransactions',
            'previousRevenuePerTransaction',
            'grossProfitMargin',
            'netProfitMargin',
            'previousGrossProfitMargin',
            'previousNetProfitMargin',
            'chartData'
        ));
    }




    public function change_password(){
        return view('admin.modules.change_password.password_update_form');
    }

    public function save_change_password(Request $request){
        $user_id =  Auth::user()->id;
        User::find($user_id)->fill([
            'password' => Hash::make($request->new_password)
        ])->save();
        return redirect()->to('module/change_password')->with('message', 'Password updated');
    }

}
