<?php

namespace App\Http\Controllers;

use App\Models\Expense;
use App\Models\Expense_head;
use App\Models\Restaurant;
use Carbon\Carbon;
use Illuminate\Http\Request;

class ExpenseController extends Controller
{
    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate');
    }

    public function index()
    {
        $results = Expense::orderBy('id','desc')->paginate(20);
        //return $results;
        return view('admin.expense.expense_list', compact('results'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $restaurants = Restaurant::pluck('name','id');
        $expense_head = Expense_head::pluck('head', 'id');
        return view('admin.expense.create', compact('restaurants', 'expense_head'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        Expense::create($request->all());
        return redirect('module/expense')->with('success','Expense created...');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

    public function daily_report(Request $request){
        $from = Carbon::now()->startOfMonth();
        if ($request->has('from')) {
            $from = $request->from;
        }
        $to = Carbon::now()->endOfMonth();
        if ($request->has('to')) {
            $to = $request->to;
        }
        $restaurantId = Restaurant::first()->id;
        if ($request->has('restaurant_id')) {
            $restaurantId = $request->restaurant_id;
        }
        $restaurants = Restaurant::pluck('name', 'id');

        $expense_date_list = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->groupBy('expense_date')
            ->pluck('expense_date')
            ->toArray();
        sort($expense_date_list);

        $staff_cost_id = Expense_head::where('parent_id',1)->pluck('id')->toArray();
        array_push($staff_cost_id, 1);

        $food_cost_id =  Expense_head::where('parent_id',2)->pluck('id')->toArray();
        array_push($food_cost_id, 2);

        $office_cost_id =  Expense_head::where('parent_id',3)->pluck('id')->toArray();
        array_push($office_cost_id, 3);

        $marketing_cost_id =  Expense_head::where('parent_id',4)->pluck('id')->toArray();
        array_push($marketing_cost_id, 4);
        //return $marketing_cost_id;
        $operation_cost_id = array_merge($office_cost_id, $marketing_cost_id);

        $expense_heads = Expense_head::get();
        $expenses  = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->get();

        return view('admin.expense.daily_report', compact('expense_date_list', 'staff_cost_id', 'food_cost_id',
            'office_cost_id', 'marketing_cost_id', 'expenses', 'restaurants', 'expense_heads', 'operation_cost_id'));

    }

    public function weekly_report(Request $request){
        $from = Carbon::now()->startOfMonth();
        if ($request->has('from')) {
            $from = $request->from;
        }
        $to = Carbon::now()->endOfMonth();
        if ($request->has('to')) {
            $to = $request->to;
        }
        $restaurantId = Restaurant::first()->id;
        if ($request->has('restaurant_id')) {
            $restaurantId = $request->restaurant_id;
        }
        $restaurants = Restaurant::pluck('name', 'id');

        $expense_date_list = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->groupBy(\DB::raw('YEARWEEK(expense_date, 1)'))
            ->pluck(\DB::raw('YEARWEEK(expense_date, 1)'))
            ->toArray();
        sort($expense_date_list);

        $staff_cost_id = Expense_head::where('parent_id', 1)->pluck('id')->toArray();
        array_push($staff_cost_id, 1);

        $food_cost_id = Expense_head::where('parent_id', 2)->pluck('id')->toArray();
        array_push($food_cost_id, 2);

        $office_cost_id = Expense_head::where('parent_id', 3)->pluck('id')->toArray();
        array_push($office_cost_id, 3);

        $marketing_cost_id = Expense_head::where('parent_id', 4)->pluck('id')->toArray();
        array_push($marketing_cost_id, 4);

        $operation_cost_id = array_merge($office_cost_id, $marketing_cost_id);

        $expense_heads = Expense_head::get();
        $expenses = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->get();

        return view('admin.expense.weekly_report', compact('expense_date_list', 'staff_cost_id', 'food_cost_id', 'office_cost_id', 'marketing_cost_id', 'expenses', 'restaurants', 'expense_heads', 'operation_cost_id'));
    }

    public function monthly_report(Request $request) {
        $from = Carbon::now()->startOfYear();
        if ($request->has('from')) {
            $from = $request->from;
        }
        $to = Carbon::now()->endOfYear();
        if ($request->has('to')) {
            $to = $request->to;
        }
        $restaurantId = Restaurant::first()->id;
        if ($request->has('restaurant_id')) {
            $restaurantId = $request->restaurant_id;
        }
        $restaurants = Restaurant::pluck('name', 'id');

        $expense_date_list = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->groupBy(\DB::raw('DATE_FORMAT(expense_date, "%Y-%m")'))
            ->pluck(\DB::raw('DATE_FORMAT(expense_date, "%Y-%m")'))
            ->toArray();
        sort($expense_date_list);

        $staff_cost_id = Expense_head::where('parent_id', 1)->pluck('id')->toArray();
        array_push($staff_cost_id, 1);

        $food_cost_id = Expense_head::where('parent_id', 2)->pluck('id')->toArray();
        array_push($food_cost_id, 2);

        $office_cost_id = Expense_head::where('parent_id', 3)->pluck('id')->toArray();
        array_push($office_cost_id, 3);

        $marketing_cost_id = Expense_head::where('parent_id', 4)->pluck('id')->toArray();
        array_push($marketing_cost_id, 4);

        $operation_cost_id = array_merge($office_cost_id, $marketing_cost_id);

        $expense_heads = Expense_head::get();
        $expenses = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->get();

        return view('admin.expense.monthly_report', compact('expense_date_list', 'staff_cost_id', 'food_cost_id', 'office_cost_id', 'marketing_cost_id', 'expenses', 'restaurants', 'expense_heads', 'operation_cost_id'));
    }

}
