<?php

namespace App\Http\Controllers;

use App\Models\Expense;
use App\Models\Expense_head;
use App\Models\Restaurant;
use App\Models\Revenue;
use App\Models\Sales_portal;
use Carbon\Carbon;
use Illuminate\Http\Request;

class RevenueController extends Controller
{
    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate');
    }

    public function index(){
        $results = Revenue::orderBy('id', 'desc')->paginate(30);
        //return $results;
        $restaurants = Restaurant::pluck('id','name');
        //return $results;
        return view('admin.revenue.revenue_list',compact('results', 'restaurants'));
    }
    public function create(){
        $restaurants = Restaurant::pluck('name','id');
        $sales_portal = Sales_portal::get();
        //return $sales_portal;
        return view('admin.revenue.create', compact('restaurants', 'sales_portal'));
    }

    public function store(Request $request){
        $input['restaurant_id'] = $request->restaurant_id;
        $input['revenue_date'] = $request->revenue_date;
        foreach($request->sales_portal_id as $index=>$protal_id){
            $no_of_transaction = $request->number_of_transaction[$index];
            $revenue = $request->revenue_after_commission[$index];
            Revenue::updateOrCreate(
                [
                    'restaurant_id'=>$request->restaurant_id,
                    'sales_portal_id'=>$protal_id,
                    'revenue_date' => $request->revenue_date
                ],
                [
                    'number_of_transaction' => $no_of_transaction ? $no_of_transaction : 0,
                    'revenue_after_commission' => $revenue ? $revenue : 0,
                ]
            );
        }
        return redirect('module/revenue')->with('success','Revenue input saved');
    }

    public function edit($revenue_input_id){
        $result = Revenue::find($revenue_input_id);
        $restaurants = Restaurant::pluck('name','id');
        $sales_portal = Sales_portal::pluck('name', 'id');
        return view('admin.revenue.edit',compact('result','restaurants', 'sales_portal'));
    }
    public function update($revenue_input_id, Request $request){
        Revenue::find($revenue_input_id)->fill($request->all())->save();
        return redirect('module/revenue')->with('success','Revenue input updated');
    }
    public function daily_report(Request $request){
        $from = Carbon::now()->startOfMonth();
        if($request->has('from')){
            $from = $request->from;
        }
        $to = Carbon::now()->endOfMonth();
        if($request->has('to')){
            $to = $request->to;
        }
        $restaurantId = Restaurant::first()->id;
        if($request->has('restaurant_id')){
            $restaurantId = $request->restaurant_id;
        }
        $restaurants = Restaurant::pluck('name','id');
        $revenue_date_list = Revenue::whereBetween('revenue_date',[$from,$to])->where('restaurant_id',$restaurantId)->groupBy('revenue_date')->pluck('revenue_date')->toArray();
        $expense_date_list = Expense::whereBetween('expense_date',[$from,$to])->where('restaurant_id',$restaurantId)->groupBy('expense_date')->pluck('expense_date')->toArray();
        $date_list = array_unique(array_merge($revenue_date_list,$expense_date_list));
        rsort($date_list);
        $sales_portal = Sales_portal::with(['revenue'=>function($query) use($from, $to, $restaurantId){
            return $query->whereBetween('revenue_date',[$from, $to])->where('restaurant_id', $restaurantId)->select('restaurant_id', 'sales_portal_id', 'revenue_date', 'number_of_transaction', 'revenue_after_commission');
        }])->get();
        //return $sales_portal;

        $staff_cost_id = Expense_head::where('parent_id',1)->pluck('id')->toArray();
        array_push($staff_cost_id, 1);

        $food_cost_id =  Expense_head::where('parent_id',2)->pluck('id')->toArray();
        array_push($food_cost_id, 2);

        $office_cost_id =  Expense_head::where('parent_id',3)->pluck('id')->toArray();
        array_push($office_cost_id, 3);

        $marketing_cost =  Expense_head::where('parent_id',4)->pluck('id')->toArray();
        array_push($marketing_cost);

        $expense_head_ids = array_merge($staff_cost_id, $food_cost_id, $office_cost_id, $marketing_cost);
        $expense = Expense::whereIn('expense_head_id', $expense_head_ids)->where('restaurant_id', $restaurantId)->get();
        $operation_cost_ids = array_merge($office_cost_id, $marketing_cost);
        //return $operation_cost_ids;
        return view('admin.revenue.daily_report', compact('date_list', 'sales_portal',  'expense', 'staff_cost_id', 'food_cost_id', 'office_cost_id', 'marketing_cost', 'restaurants', 'operation_cost_ids'));
    }

    public function weekly_report(Request $request) {
        $from = Carbon::now()->startOfMonth();
        if($request->has('from')){
            $from = $request->from;
        }
        $to = Carbon::now()->endOfMonth();
        if($request->has('to')){
            $to = $request->to;
        }
        $restaurantId = Restaurant::first()->id;
        if($request->has('restaurant_id')){
            $restaurantId = $request->restaurant_id;
        }
        $restaurants = Restaurant::pluck('name', 'id');

        // Group by week and select the start of the week as the reference date
        $revenue_date_list = Revenue::whereBetween('revenue_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->selectRaw('YEARWEEK(revenue_date, 1) as week')
            ->groupBy('week')
            ->pluck('week')
            ->toArray();

        $expense_date_list = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->selectRaw('YEARWEEK(expense_date, 1) as week')
            ->groupBy('week')
            ->pluck('week')
            ->toArray();
        //return $expense_date_list;
        $week_list = array_unique(array_merge($revenue_date_list, $expense_date_list));
        rsort($week_list);
        //return $week_list;
        $sales_portal = Sales_portal::with(['revenue' => function($query) use($from, $to, $restaurantId) {
            return $query->whereBetween('revenue_date', [$from, $to])
                ->where('restaurant_id', $restaurantId)
                ->select('restaurant_id', 'sales_portal_id', 'revenue_date', 'number_of_transaction', 'revenue_after_commission');
        }])->get();

        $staff_cost_id = Expense_head::where('parent_id', 1)->pluck('id')->toArray();
        array_push($staff_cost_id, 1);

        $food_cost_id = Expense_head::where('parent_id', 2)->pluck('id')->toArray();
        array_push($food_cost_id, 2);

        $office_cost_id = Expense_head::where('parent_id', 3)->pluck('id')->toArray();
        array_push($office_cost_id, 3);

        $marketing_cost = Expense_head::where('parent_id', 4)->pluck('id')->toArray();
        array_push($marketing_cost);

        $expense_head_ids = array_merge($staff_cost_id, $food_cost_id, $office_cost_id, $marketing_cost);
        //return $expense_head_ids;
        //return Carbon::parse('2024-05-30')->format('oW');
        $expense = Expense::whereIn('expense_head_id', $expense_head_ids)
            ->where('restaurant_id', $restaurantId)
            ->get();
        $operation_cost_ids = array_merge($office_cost_id, $marketing_cost);

        return view('admin.revenue.weekly_report', compact('week_list', 'sales_portal', 'expense', 'staff_cost_id', 'food_cost_id', 'office_cost_id', 'marketing_cost', 'restaurants', 'operation_cost_ids'));
    }

    public function monthly_report(Request $request) {
        $from = Carbon::now()->startOfYear();
        if($request->has('from')){
            $from = $request->from;
        }
        $to = Carbon::now()->endOfYear();
        if($request->has('to')){
            $to = $request->to;
        }
        $restaurantId = Restaurant::first()->id;
        if($request->has('restaurant_id')){
            $restaurantId = $request->restaurant_id;
        }
        $restaurants = Restaurant::pluck('name', 'id');

        // Group by month
        $revenue_date_list = Revenue::whereBetween('revenue_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->selectRaw('DATE_FORMAT(revenue_date, "%Y-%m") as month')
            ->groupBy('month')
            ->pluck('month')
            ->toArray();

        $expense_date_list = Expense::whereBetween('expense_date', [$from, $to])
            ->where('restaurant_id', $restaurantId)
            ->selectRaw('DATE_FORMAT(expense_date, "%Y-%m") as month')
            ->groupBy('month')
            ->pluck('month')
            ->toArray();

        $month_list = array_unique(array_merge($revenue_date_list, $expense_date_list));

        $sales_portal = Sales_portal::with(['revenue' => function($query) use($from, $to, $restaurantId) {
            return $query->whereBetween('revenue_date', [$from, $to])
                ->where('restaurant_id', $restaurantId)
                ->select('restaurant_id', 'sales_portal_id', 'revenue_date', 'number_of_transaction', 'revenue_after_commission');
        }])->get();

        $staff_cost_id = Expense_head::where('parent_id', 1)->pluck('id')->toArray();
        array_push($staff_cost_id, 1);

        $food_cost_id = Expense_head::where('parent_id', 2)->pluck('id')->toArray();
        array_push($food_cost_id, 2);

        $office_cost_id = Expense_head::where('parent_id', 3)->pluck('id')->toArray();
        array_push($office_cost_id, 3);
        //return $staff_cost_id;
        $marketing_cost = Expense_head::where('parent_id', 4)->pluck('id')->toArray();
        array_push($marketing_cost);

        $expense_head_ids = array_merge($staff_cost_id, $food_cost_id, $office_cost_id, $marketing_cost);
        $operation_cost_ids = array_merge($office_cost_id, $marketing_cost);
        $expense = Expense::whereIn('expense_head_id', $expense_head_ids)
            ->where('restaurant_id', $restaurantId)
            ->get();
        //return $expense;

        return view('admin.revenue.monthly_report', compact('month_list', 'sales_portal', 'expense', 'staff_cost_id', 'food_cost_id', 'office_cost_id', 'marketing_cost', 'restaurants','operation_cost_ids'));
    }


}
